# Automatically built by dist/s_test; may require local editing.

set tclsh_path SET_YOUR_TCLSH_PATH
set buildpath Win32/Debug
set tcllib libdb_tcl53d.dll

set src_root ..
set test_path ../test/tcl
set je_root ../../je
set tcl_utils ../test/tcl_utils

global testdir
set testdir ./TESTDIR

global dict
global util_path

global is_freebsd_test
global is_hp_test
global is_linux_test
global is_osx_test
global is_qnx_test
global is_sunos_test
global is_windows_test
global is_windows9x_test

global valid_methods
global checking_valid_methods
global test_recopts

set KILL dbkill.exe
